[//]: # (help) Quick overview of eh
# How to use eh

Eh a few ways be used:

##

### Primary Use:

- `eh topic` - will display information for **topic** or, if parent topic, list the children
- `eh parent topic` - will display information for **topic** under parent

##

### Support Usage:

- `eh list` - will list the topics (same as running with no arguments)
- `eh update` - will update configured topic repos
